README — turbo-turtle 1.2.9 documentation

Skip to main content
`Ctrl`+`K`

# README

## Description

Turbo-Turtle (LANL code O4765) is a collection of solid body modeling tools for 2D sketched, 2D axisymmetric, and 3D revolved models. It also contains general purpose meshing and image generation utilities appropriate for any model, not just those created with this package. Implemented for Abaqus and Cubit as backend modeling and meshing software. Orginal implementation targeted Abaqus so most options and descriptions use Abaqus modeling concepts and language.

Turbo-Turtle makes a best effort to maintain common behaviors and features across each third-party software’s modeling concepts. As much as possible, the work for each subcommand is performed in Python 3 to minimize solution approach duplication in third-party tools. The third-party scripting interface is only accessed when creating the final tool specific objects and output. The tools contained in this project can be expanded to drive other meshing utilities in the future, as needed by the user community.

This project derives its name from the origins as a sphere partitioning utility following the turtle shell (or soccer ball) pattern.

### Documentation

- GitHub: https://lanl-aea.github.io/turbo-turtle/

- LANL: https://aea.re-pages.lanl.gov/python-projects/turbo-turtle/

### Author Info

- Kyle Brindley

- Thomas Roberts

## Installation

### Conda

Turbo-Turtle can be installed in a Conda environment with the Conda package manager. See the Conda installation and Conda environment management documentation for more details about using Conda.

    $ conda install --channel conda-forge turbo_turtle

### pip

Turbo-Turtle may also be installed from PyPI with pip under the distribution name `turbo-turtle`: https://pypi.org/project/turbo-turtle/.

    $ pip install turbo-turtle

The PyPI package has an optional dependency for the Gmsh features that may be specified during installation as

    $ pip install turbo-turtle[gmsh]

## Quick Start

1. View the CLI usage

       $ turbo-turtle -h
       $ turbo-turtle docs -h
       $ turbo-turtle geometry -h
       $ turbo-turtle cylinder -h
       $ turbo-turtle sphere -h
       $ turbo-turtle partition -h
       $ turbo-turtle mesh -h
       $ turbo-turtle image -h
       $ turbo-turtle merge -h
       $ turbo-turtle export -h

## Copyright Notice

Copyright (c) 2024, Triad National Security, LLC. All rights reserved.

This program was produced under U.S. Government contract 89233218CNA000001 for Los Alamos National Laboratory (LANL), which is operated by Triad National Security, LLC for the U.S. Department of Energy/National Nuclear Security Administration. All rights in the program are reserved by Triad National Security, LLC, and the U.S. Department of Energy/National Nuclear Security Administration. The Government is granted for itself and others acting on its behalf a nonexclusive, paid-up, irrevocable worldwide license in this material to reproduce, prepare derivative works, distribute copies to the public, perform publicly and display publicly, and to permit others to do so.

## Developer Instructions

### Cloning the Repository

Cloning the repository is very easy, simply refer to the sample session below. Keep in mind that you get to choose the location of your local Turbo-Turtle repository clone. Here we use `/projects/roppenheimer/repos` as an example.

    [roppenheimer@sstelmo repos]$ git clone ssh://git@re-git.lanl.gov:10022/aea/python-projects/turbo-turtle.git

### Compute Environment

This project uses Conda to manage most of the compute environment. Some software, e.g. Abaqus and Cubit, can not be installed with Conda and must be installed separately.

SCons can be installed in a Conda environment with the Conda package manager. See the Conda installation and Conda environment management documentation for more details about using Conda.

1. Create the environment if it doesn’t exist

       $ conda env create --name berms-env --file environment.yml

2. Activate the environment

       $ conda activate berms-env

### Testing

This project now performs CI testing on AEA compute servers. The up-to-date test commands can be found in the `.gitlab-ci.yml` file. The full regression suite includes the documentation builds, Python 3 unit tests, Abaqus Python unit tests, and the system tests.

    $ pwd
    /home/roppenheimer/repos/turbo-turtle
    $ scons regression

There is also a separate style guide check run as

    $ scons style

The full list of available aliases can be found as `scons -h`.